HyperlitConfig

Struct HyperlitConfig 

pub struct HyperlitConfig {
    pub config_path: String,
    pub src_directory: String,
    pub src_globs: Vec<String>,
    pub docs_directory: String,
    pub doc_globs: Vec<String>,
    pub build_directory: String,
    pub output_directory: String,
    pub doc_markers: Vec<String>,
    pub source_link_template: Option<String>,
}
Hyperlit configuration used to configure the document generation process

Fields

config_path: String

path to the hyperlit.toml file

src_directory: String

Root path to source code. This may be the repository root to collect all files

src_globs: Vec<String>

Globs to use when searching for source files, these may be prefixed with “!” to exclude files or directories

docs_directory: String

Path to the docs directory

doc_globs: Vec<String>

Globs to use when searching for documentation files, may be “*” to include all files

build_directory: String

Path to a build directory used for temporary files

output_directory: String

Directory to write the complete documentation output to

doc_markers: Vec<String>

List of marker strings used to identify documentation segments to extract from the source code

source_link_template: Option<String>

Template used to generate links to source code (e.g. on github, etc.)

Implementations

Source

impl HyperlitConfig

pub fn from_path(path: impl AsRef<Path>) -> HyperlitResult<Self>

pub fn from_string(string: &str) -> HyperlitResult<Self>